summaryrefslogtreecommitdiffstats
path: root/src/kpowersave.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:24:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:24:41 -0600
commite3830e4c08b5b58945714e698d5745f15ed60189 (patch)
tree0fd616be7989804dca4201562652ea065bfab910 /src/kpowersave.h
parentc38f8eb7efad25d59afa3d96fe2f59a2821a82ae (diff)
downloadkpowersave-e3830e4c08b5b58945714e698d5745f15ed60189.tar.gz
kpowersave-e3830e4c08b5b58945714e698d5745f15ed60189.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'src/kpowersave.h')
-rw-r--r--src/kpowersave.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/kpowersave.h b/src/kpowersave.h
index 7715392..4ff6a3d 100644
--- a/src/kpowersave.h
+++ b/src/kpowersave.h
@@ -88,8 +88,8 @@ private:
autodimm * autoDimm;
// temporary pointer, use them if needed
- //! KProcess to start YaST-module for configuration
- KProcess *yast2;
+ //! TDEProcess to start YaST-module for configuration
+ TDEProcess *yast2;
//! instance of \ref ConfigureDialog
/*! the implemtation and all related functions for the configure dialog*/
ConfigureDialog *configDlg;
@@ -351,7 +351,7 @@ private slots:
//! sets the CPU Freq policy via the HAL daemon
void do_setSpeedPolicy( int );
//! called if there are problems with starting yast module
- void slotConfigProcessExited( KProcess * );
+ void slotConfigProcessExited( TDEProcess * );
//! called to open the kpowersave help
void slotHelp();
//! called to open the kpowersave About dialog